@@ -14,7 +14,7 @@ A small library for parsing configuration files.
 Supports secsie and ini formats. Not suitable for writing .ini files, but reads them just fine.
 """
 
-__version__ = 'v1.0.2'
+__version__ = 'v1.0.3'
 __author__ = 'Noah Broyles'
 
 
@@ -116,8 +116,11 @@ def generate_config(obj: dict, output_file: str = None) -> str:
     Will save the config if an output file is passed.
     
     This WILL NOT write valid .ini files, so don't even try. The only output format is secsie."""
-    output_file = Path(output_file)
-    conf = f"# {output_file.name} auto-generated by secsie\n\n"
+    if output_file is not None:
+        output_file = Path(output_file)
+        conf = f"# {output_file.name} auto-generated by secsie\n\n"
+    else:
+        conf = ''
     for key, value in obj.items():
         if isinstance(value, dict):
             conf += f"\n[{key.replace(' ', '')}]\n"
@@ -127,7 +130,7 @@ def generate_config(obj: dict, output_file: str = None) -> str:
             continue
         conf += f"{key} = {value}\n"
 
-    if output_file:
+    if output_file is not None:
         with open(output_file, 'w') as f:
             f.write(conf)
 
